@@ -1,20 +1,14 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: a_1.c,v 1.8 2009/12/04 22:06:37 tbox Exp $ */
 
 /* by Bjorn.Victor@it.uu.se, 2005-05-07 */
 /* Based on generic/soa_6.c and generic/mx_15.c */
@@ -39,7 +33,7 @@ fromtext_ch_a(ARGS_FROMTEXT) {
 	UNUSED(callbacks);
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      ISC_FALSE));
+				      false));
 
 	/* get domain name */
 	dns_name_init(&name, NULL);
@@ -49,8 +43,8 @@ fromtext_ch_a(ARGS_FROMTEXT) {
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 	if ((options & DNS_RDATA_CHECKNAMES) != 0 &&
 	    (options & DNS_RDATA_CHECKREVERSE) != 0) {
-		isc_boolean_t ok;
-		ok = dns_name_ishostname(&name, ISC_FALSE);
+		bool ok;
+		ok = dns_name_ishostname(&name, false);
 		if (!ok && (options & DNS_RDATA_CHECKNAMESFAIL) != 0)
 			RETTOK(DNS_R_BADNAME);
 		if (!ok && callbacks != NULL)
@@ -58,7 +52,7 @@ fromtext_ch_a(ARGS_FROMTEXT) {
 	}
 
 	/* 16-bit octal address */
-	RETERR(isc_lex_getoctaltoken(lexer, &token, ISC_FALSE));
+	RETERR(isc_lex_getoctaltoken(lexer, &token, false));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	return (uint16_tobuffer(token.value.as_ulong, target));
@@ -69,9 +63,9 @@ totext_ch_a(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
 	dns_name_t prefix;
-	isc_boolean_t sub;
+	bool sub;
 	char buf[sizeof("0177777")];
-	isc_uint16_t addr;
+	uint16_t addr;
 
 	REQUIRE(rdata->type == dns_rdatatype_a);
 	REQUIRE(rdata->rdclass == dns_rdataclass_ch); /* 3 */
@@ -185,7 +179,7 @@ compare_ch_a(ARGS_COMPARE) {
 	if (order != 0)
 		return (order);
 
-	order = memcmp(rdata1->data, rdata2->data, 2);
+	order = memcmp(region1.base, region2.base, 2);
 	if (order != 0)
 		order = (order < 0) ? -1 : 1;
 	return (order);
@@ -193,13 +187,15 @@ compare_ch_a(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_ch_a(ARGS_FROMSTRUCT) {
-	dns_rdata_ch_a_t *a = source;
+	dns_rdata_ch_a_t *a;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_a);
-	REQUIRE(source != NULL);
-	REQUIRE(a->common.rdtype == type);
-	REQUIRE(a->common.rdclass == rdclass);
+	REQUIRE(((dns_rdata_ch_a_t *)source) != NULL);
+	REQUIRE(((dns_rdata_ch_a_t *)source)->common.rdtype == type);
+	REQUIRE(((dns_rdata_ch_a_t *)source)->common.rdclass == rdclass);
+
+	a = source;
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -212,7 +208,7 @@ fromstruct_ch_a(ARGS_FROMSTRUCT) {
 
 static inline isc_result_t
 tostruct_ch_a(ARGS_TOSTRUCT) {
-	dns_rdata_ch_a_t *a = target;
+	dns_rdata_ch_a_t *a;
 	isc_region_t region;
 	dns_name_t name;
 
@@ -220,6 +216,8 @@ tostruct_ch_a(ARGS_TOSTRUCT) {
 	REQUIRE(rdata->rdclass == dns_rdataclass_ch);
 	REQUIRE(rdata->length != 0);
 
+	a = target;
+
 	a->common.rdclass = rdata->rdclass;
 	a->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&a->common, link);
@@ -239,10 +237,12 @@ tostruct_ch_a(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_ch_a(ARGS_FREESTRUCT) {
-	dns_rdata_ch_a_t *a = source;
+	dns_rdata_ch_a_t *a;
 
-	REQUIRE(source != NULL);
-	REQUIRE(a->common.rdtype == dns_rdatatype_a);
+	REQUIRE(((dns_rdata_ch_a_t *)source) != NULL);
+	REQUIRE(((dns_rdata_ch_a_t *)source)->common.rdtype == dns_rdatatype_a);
+
+	a = source;
 
 	if (a->mctx == NULL)
 		return;
@@ -280,7 +280,7 @@ digest_ch_a(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline isc_boolean_t
+static inline bool
 checkowner_ch_a(ARGS_CHECKOWNER) {
 
 	REQUIRE(type == dns_rdatatype_a);
@@ -291,7 +291,7 @@ checkowner_ch_a(ARGS_CHECKOWNER) {
 	return (dns_name_ishostname(name, wildcard));
 }
 
-static inline isc_boolean_t
+static inline bool
 checknames_ch_a(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -304,13 +304,13 @@ checknames_ch_a(ARGS_CHECKNAMES) {
 	dns_rdata_toregion(rdata, &region);
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &region);
-	if (!dns_name_ishostname(&name, ISC_FALSE)) {
+	if (!dns_name_ishostname(&name, false)) {
 		if (bad != NULL)
 			dns_name_clone(&name, bad);
-		return (ISC_FALSE);
+		return (false);
 	}
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static inline int
