@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -32,13 +32,13 @@ fromtext_nid(ARGS_FROMTEXT) {
 	UNUSED(callbacks);
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      ISC_FALSE));
+				      false));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      ISC_FALSE));
+				      false));
 
 	if (locator_pton(DNS_AS_STR(token), locator) != 1)
 		RETTOK(DNS_R_SYNTAX);
@@ -119,12 +119,14 @@ compare_nid(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_nid(ARGS_FROMSTRUCT) {
-	dns_rdata_nid_t *nid = source;
+	dns_rdata_nid_t *nid;
 
 	REQUIRE(type == dns_rdatatype_nid);
-	REQUIRE(source != NULL);
-	REQUIRE(nid->common.rdtype == type);
-	REQUIRE(nid->common.rdclass == rdclass);
+	REQUIRE(((dns_rdata_nid_t *)source) != NULL);
+	REQUIRE(((dns_rdata_nid_t *)source)->common.rdtype == type);
+	REQUIRE(((dns_rdata_nid_t *)source)->common.rdclass == rdclass);
+
+	nid = source;
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -136,12 +138,14 @@ fromstruct_nid(ARGS_FROMSTRUCT) {
 static inline isc_result_t
 tostruct_nid(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_nid_t *nid = target;
+	dns_rdata_nid_t *nid;
 
+	REQUIRE(((dns_rdata_nid_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_nid);
-	REQUIRE(target != NULL);
 	REQUIRE(rdata->length == 10);
 
+	nid = target;
+
 	UNUSED(mctx);
 
 	nid->common.rdclass = rdata->rdclass;
@@ -156,10 +160,9 @@ tostruct_nid(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_nid(ARGS_FREESTRUCT) {
-	dns_rdata_nid_t *nid = source;
-
-	REQUIRE(source != NULL);
-	REQUIRE(nid->common.rdtype == dns_rdatatype_nid);
+	REQUIRE(((dns_rdata_nid_t *)source) != NULL);
+	REQUIRE(((dns_rdata_nid_t *)source)->common.rdtype ==
+		dns_rdatatype_nid);
 
 	return;
 }
@@ -189,7 +192,7 @@ digest_nid(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline isc_boolean_t
+static inline bool
 checkowner_nid(ARGS_CHECKOWNER) {
 
 	REQUIRE(type == dns_rdatatype_nid);
@@ -199,10 +202,10 @@ checkowner_nid(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
-static inline isc_boolean_t
+static inline bool
 checknames_nid(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_nid);
@@ -212,7 +215,7 @@ checknames_nid(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (ISC_TRUE);
+	return (true);
 }
 
 static inline int
