@@ -1,12 +1,14 @@
 /*
- * Copyright (C) 2009, 2012-2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id: sample-request.c,v 1.5 2009/09/29 15:06:07 fdupont Exp $ */
 
 #include <config.h>
 
@@ -81,11 +83,10 @@ make_querymessage(dns_message_t *message, const char *namestr,
 	namelen = strlen(namestr);
 	isc_buffer_constinit(&b, namestr, namelen);
 	isc_buffer_add(&b, namelen);
-	dns_fixedname_init(&fixedqname);
-	qname0 = dns_fixedname_name(&fixedqname);
+	qname0 = dns_fixedname_initname(&fixedqname);
 	result = dns_name_fromtext(qname0, &b, dns_rootname, 0, NULL);
 	if (result != ISC_R_SUCCESS) {
-		fprintf(stderr, "failed to convert qname: %d\n", result);
+		fprintf(stderr, "failed to convert qname: %u\n", result);
 		return (result);
 	}
 
@@ -114,7 +115,7 @@ make_querymessage(dns_message_t *message, const char *namestr,
 		dns_message_puttempname(message, &qname);
 	if (qrdataset != NULL)
 		dns_message_puttemprdataset(message, &qrdataset);
-	dns_message_destroy(&message);
+	dns_message_detach(&message);
 	return (result);
 }
 
@@ -175,13 +176,13 @@ main(int argc, char *argv[]) {
 	isc_lib_register();
 	result = dns_lib_init();
 	if (result != ISC_R_SUCCESS) {
-		fprintf(stderr, "dns_lib_init failed: %d\n", result);
+		fprintf(stderr, "dns_lib_init failed: %u\n", result);
 		exit(1);
 	}
 
 	result = dns_client_create(&client, 0);
 	if (result != ISC_R_SUCCESS) {
-		fprintf(stderr, "dns_client_create failed: %d\n", result);
+		fprintf(stderr, "dns_client_create failed: %u\n", result);
 		exit(1);
 	}
 
@@ -254,8 +255,8 @@ main(int argc, char *argv[]) {
 	isc_buffer_free(&outputbuf);
 
 	/* Cleanup */
-	dns_message_destroy(&qmessage);
-	dns_message_destroy(&rmessage);
+	dns_message_detach(&qmessage);
+	dns_message_detach(&rmessage);
 	isc_mem_destroy(&mctx);
 	dns_client_destroy(&client);
 	dns_lib_shutdown();
